@@ -1,16 +1,18 @@
 package DateTime::Locale;
 
-use 5.008001;
+use 5.008004;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.02';
+our $VERSION = '1.17';
 
 use DateTime::Locale::Data;
 use DateTime::Locale::FromData;
 use DateTime::Locale::Util qw( parse_locale_code );
-use Params::Validate qw( validate validate_pos SCALAR );
+use Params::ValidationCompiler 0.13 qw( validation_for );
+use Specio::Library::String;
 
 my %Class;
 my %DataForCode;
@@ -34,26 +36,8 @@ sub register {
 }
 
 sub _register {
-    my $class = shift;
-
-    my %p = validate(
-        @_, {
-            id => { type => SCALAR },
-
-            en_language  => { type => SCALAR },
-            en_script    => { type => SCALAR, optional => 1 },
-            en_territory => { type => SCALAR, optional => 1 },
-            en_variant   => { type => SCALAR, optional => 1 },
-
-            native_language  => { type => SCALAR, optional => 1 },
-            native_script    => { type => SCALAR, optional => 1 },
-            native_territory => { type => SCALAR, optional => 1 },
-            native_variant   => { type => SCALAR, optional => 1 },
-
-            class   => { type => SCALAR, optional => 1 },
-            replace => { type => SCALAR, default  => 0 },
-        }
-    );
+    shift;
+    my %p = @_;
 
     my $id = $p{id};
 
@@ -121,7 +105,7 @@ sub remove_alias {
 
     %LoadCache = ();
 
-    my ($alias) = validate_pos( @_, { type => SCALAR } );
+    my $alias = shift;
 
     return delete $UserDefinedAlias{$alias};
 }
@@ -186,57 +170,67 @@ my %POSIXAliases = (
     POSIX => 'en-US-POSIX',
 );
 
-sub load {
-    my $class = shift;
-    my ($code) = validate_pos( @_, { type => SCALAR } );
+{
+    my $validator = validation_for(
+        name             => '_check_load_params',
+        name_is_optional => 1,
+        params           => [
+            { type => t('NonEmptyStr') },
+        ],
+    );
 
-    # We used to use underscores in codes instead of dashes. We want to
-    # support both indefinitely.
-    $code =~ tr/_/-/;
+    sub load {
+        my $class = shift;
+        my ($code) = $validator->(@_);
 
-    # Strip off charset for LC_* codes : en_GB.UTF-8 etc
-    $code =~ s/\..*$//;
+        # We used to use underscores in codes instead of dashes. We want to
+        # support both indefinitely.
+        $code =~ tr/_/-/;
 
-    return $LoadCache{$code} if exists $LoadCache{$code};
+        # Strip off charset for LC_* codes : en_GB.UTF-8 etc
+        $code =~ s/\..*$//;
 
-    while ( exists $UserDefinedAlias{$code} ) {
-        $code = $UserDefinedAlias{$code};
+        return $LoadCache{$code} if exists $LoadCache{$code};
+
+        while ( exists $UserDefinedAlias{$code} ) {
+            $code = $UserDefinedAlias{$code};
+        }
+
+        $code = $DateTimeLanguageAliases{$code}
+            if exists $DateTimeLanguageAliases{$code};
+        $code = $POSIXAliases{$code} if exists $POSIXAliases{$code};
+        $code = $DateTime::Locale::Data::ISO639Aliases{$code}
+            if exists $DateTime::Locale::Data::ISO639Aliases{$code};
+
+        if ( exists $DateTime::Locale::Data::Codes{$code} ) {
+            return $class->_locale_object_for($code);
+        }
+
+        if ( exists $DateTime::Locale::Data::Names{$code} ) {
+            return $class->_locale_object_for(
+                $DateTime::Locale::Data::Names{$code} );
+        }
+
+        if ( exists $DateTime::Locale::Data::NativeNames{$code} ) {
+            return $class->_locale_object_for(
+                $DateTime::Locale::Data::NativeNames{$code} );
+        }
+
+        if ( my $locale = $class->_registered_locale_for($code) ) {
+            return $locale;
+        }
+
+        if ( my $guessed = $class->_guess_code($code) ) {
+            return $class->_locale_object_for($guessed);
+        }
+
+        die "Invalid locale code or name: $code\n";
     }
-
-    $code = $DateTimeLanguageAliases{$code}
-        if exists $DateTimeLanguageAliases{$code};
-    $code = $POSIXAliases{$code} if exists $POSIXAliases{$code};
-    $code = $DateTime::Locale::Data::ISO639Aliases{$code}
-        if exists $DateTime::Locale::Data::ISO639Aliases{$code};
-
-    if ( exists $DateTime::Locale::Data::Codes{$code} ) {
-        return $class->_locale_object_for($code);
-    }
-
-    if ( exists $DateTime::Locale::Data::Names{$code} ) {
-        return $class->_locale_object_for(
-            $DateTime::Locale::Data::Names{$code} );
-    }
-
-    if ( exists $DateTime::Locale::Data::NativeNames{$code} ) {
-        return $class->_locale_object_for(
-            $DateTime::Locale::Data::NativeNames{$code} );
-    }
-
-    if ( my $locale = $class->_registered_locale_for($code) ) {
-        return $locale;
-    }
-
-    if ( my $guessed = $class->_guess_code($code) ) {
-        return $class->_locale_object_for($guessed);
-    }
-
-    die "Invalid locale code or name: $code\n";
 }
 
 sub _guess_code {
-    my $class = shift;
-    my $code  = shift;
+    shift;
+    my $code = shift;
 
     my %codes = parse_locale_code($code);
 
@@ -360,13 +354,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Locale - Localization support for DateTime.pm
 
 =head1 VERSION
 
-version 1.02
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -374,7 +370,7 @@ version 1.02
 
   my $loc = DateTime::Locale->load('en-GB');
 
-  print $loc->native_locale_name, "\n", $loc->datetime_format_long, "\n";
+  print $loc->native_name, "\n", $loc->datetime_format_long, "\n";
 
   # but mostly just things like ...
 
@@ -390,8 +386,6 @@ locales.
 If you want to know what methods are available for locale objects, then please
 read the C<DateTime::Locale::FromData> documentation.
 
-=encoding utf8
-
 =head1 USAGE
 
 This module provides the following class methods:
@@ -458,9 +452,16 @@ reference if called in a scalar context.
 
 Returns an unsorted list of the available locale names in their native
 language, or an array reference if called in a scalar context. All native
-names in UTF-8 characters as appropriate.
+names use UTF-8 as appropriate.
 
-=head1 SUPPORT
+=head1 LOADING LOCALES IN A PRE-FORKING SYSTEM
+
+If you are running an application that does pre-forking (for example with
+Starman), then you should try to load all the locales that you'll need in the
+parent process. Locales are loaded on-demand, so loading them once in each
+child will waste memory that could otherwise be shared.
+
+=head1 CLDR DATA BUGS
 
 Please be aware that all locale data has been generated from the CLDR (Common
 Locale Data Repository) project locales data). The data is incomplete, and may
@@ -474,26 +475,6 @@ details.
 Once these errors have been confirmed, please forward the error report and
 corrections to the DateTime mailing list, datetime@perl.org.
 
-Support for this module is provided via the datetime@perl.org email list. See
-http://lists.perl.org/ for more details.
-
-=head1 DONATIONS
-
-If you'd like to thank me for the work I've done on this module, please
-consider making a "donation" to me via PayPal. I spend a lot of free time
-creating free software, and would appreciate any support you'd care to offer.
-
-Please note that B<I am not suggesting that you must do this> in order for me
-to continue working on this particular software. I will continue to do so,
-inasmuch as I have in the past, for as long as it interests me.
-
-Similarly, a donation made in this way will probably not make me work on this
-software much more, unless I get so many donations that I can consider working
-on free software full time, which seems unlikely at best.
-
-To donate, log into PayPal and send money to autarch@urth.org or use the
-button on this page: L<http://www.urth.org/~autarch/fs-donation.html>
-
 =head1 AUTHOR EMERITUS
 
 Richard Evans wrote the first version of DateTime::Locale, including the tools
@@ -507,15 +488,72 @@ datetime@perl.org mailing list
 
 http://datetime.perl.org/
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-Locale/issues>.
+
+There is a mailing list available for users of this distribution,
+L<mailto:datetime@perl.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-Locale can be found at L<https://github.com/houseabsolute/DateTime-Locale>.
+
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
+
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time (let's all have a chuckle at that together).
+
+To donate, log into PayPal and send money to autarch@urth.org, or use the
+button at L<http://www.urth.org/~autarch/fs-donation.html>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Mohammad S Anwar Sergey Leschenko yasu47b
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
+Sergey Leschenko <Sergey.Leschenko@portaone.com>
+
+=item *
+
+yasu47b <nakayamayasuhiro1986@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dave Rolsky.
+This software is copyright (c) 2003 - 2017 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
