@@ -2,13 +2,15 @@ package DateTime::Locale::Base;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.05';
+our $VERSION = '1.17';
 
 use Carp qw( carp );
 use DateTime::Locale;
 use List::Util 1.45 ();
-use Params::Validate qw( validate_pos );
+use Params::ValidationCompiler 0.13 qw( validation_for );
+use Specio::Declare;
 
 BEGIN {
     foreach my $field (
@@ -141,10 +143,16 @@ sub _available_formats { }
 
 sub default_date_format_length { $_[0]->{default_date_format_length} }
 
+my $length = enum( values => [qw( full long medium short )] );
+my $validator = validation_for(
+    name             => '_check_length_parameter',
+    name_is_optional => 1,
+    params           => [ { type => $length } ],
+);
+
 sub set_default_date_format_length {
     my $self = shift;
-    my ($l)
-        = validate_pos( @_, { regex => qr/^(?:full|long|medium|short)$/i } );
+    my ($l) = $validator->(@_);
 
     $self->{default_date_format_length} = lc $l;
 }
@@ -153,8 +161,7 @@ sub default_time_format_length { $_[0]->{default_time_format_length} }
 
 sub set_default_time_format_length {
     my $self = shift;
-    my ($l)
-        = validate_pos( @_, { regex => qr/^(?:full|long|medium|short)/i } );
+    my ($l) = $validator->(@_);
 
     $self->{default_time_format_length} = lc $l;
 }
@@ -459,8 +466,8 @@ sub STORABLE_freeze {
 }
 
 sub STORABLE_thaw {
-    my $self       = shift;
-    my $cloning    = shift;
+    my $self = shift;
+    shift;
     my $serialized = shift;
 
     my $obj = DateTime::Locale->load($serialized);
@@ -486,7 +493,7 @@ DateTime::Locale::Base - Base class for individual locale objects
 
 =head1 VERSION
 
-version 1.05
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -798,23 +805,29 @@ one exists.
 
 See L<DateTime::Locale>.
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Locale>
-(or L<bug-datetime-locale@rt.cpan.org|mailto:bug-datetime-locale@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-Locale/issues>.
 
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-Locale can be found at L<https://github.com/houseabsolute/DateTime-Locale>.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dave Rolsky.
+This software is copyright (c) 2003 - 2017 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
