@@ -2,10 +2,11 @@ package DateTime::Locale::Util;
 
 use strict;
 use warnings;
+use namespace::autoclean 0.19 -except => ['import'];
 
 use Exporter qw( import );
 
-our $VERSION = '1.05';
+our $VERSION = '1.17';
 
 our @EXPORT_OK = 'parse_locale_code';
 
@@ -19,6 +20,9 @@ sub parse_locale_code {
         if ( length $pieces[0] == 2 || $pieces[0] =~ /^\d\d\d$/ ) {
             $codes{territory} = uc shift @pieces;
         }
+        else {
+            $codes{script} = _tc( shift @pieces );
+        }
     }
     elsif ( @pieces == 3 ) {
         $codes{script}    = _tc( shift @pieces );
@@ -27,7 +31,7 @@ sub parse_locale_code {
     }
     elsif ( @pieces == 2 ) {
 
-        # I don't think it's possible to have a script + variant with also
+        # I don't think it's possible to have a script + variant without also
         # having a territory.
         if ( length $pieces[1] == 2 || $pieces[1] =~ /^\d\d\d$/ ) {
             $codes{script}    = _tc( shift @pieces );
@@ -62,7 +66,7 @@ DateTime::Locale::Util - Utility code for DateTime::Locale
 
 =head1 VERSION
 
-version 1.05
+version 1.17
 
 =head1 DESCRIPTION
 
@@ -70,23 +74,29 @@ There are no user-facing parts in this module.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Locale>
-(or L<bug-datetime-locale@rt.cpan.org|mailto:bug-datetime-locale@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-Locale/issues>.
 
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-Locale can be found at L<https://github.com/houseabsolute/DateTime-Locale>.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dave Rolsky.
+This software is copyright (c) 2003 - 2017 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
